%module config

%{
#include "libharkio3.h"
#include "libharkio3_macros.h"
#define HARKIO_LOG_INITIAL_LEVEL harkio_Log_Error

%}

typedef struct{
    char *comment;          /*!< コメントに使用する任意の文字列  */
    int synchronousAverage; /*!< TSPの同期加算回数      */
    char *TSPpath;          /*!< TSPの元信号へのパス  */
    int TSPoffset;          /*!< TSPが開始するまでのオフセット [サンプル]  */
    int TSPLength;          /*!< 収録するTSP信号の長さ [サンプル]  */
    int peakSearchFrom;     /*!< インパルス応答のピーク検索範囲の開始位置  */
    int peakSearchTo;       /*!< インパルス応答のピーク検索範囲の終了位置  */
    int nfft;               /*!< FFT長  */
    int samplingRate;       /*!< 音響信号ファイルのサンプリング周波数  */
    int signalMax;          /*!< 音響信号ファイルの振幅の最大値  */
} harkio_Config;


%extend harkio_Config {
    char *__str__(){
        return harkio_Config_printBuffer($self);
    }
};

harkio_Config* harkio_Config_new(void);
harkio_Config* harkio_Config_copy(harkio_Config *cfg);
void harkio_Config_delete(harkio_Config **cfg);

int harkio_Config_getSynchronousAverage(harkio_Config *cfg);
char *harkio_Config_getTSPpath(harkio_Config *cfg);
int harkio_Config_getTSPoffset(harkio_Config *cfg);
int harkio_Config_getPeakSearchFrom(harkio_Config *cfg);
int harkio_Config_getPeakSearchTo(harkio_Config *cfg);
int harkio_Config_getNfft(harkio_Config *cfg);
int harkio_Config_getSamplingRate(harkio_Config *cfg);
int harkio_Config_getTSPLength(harkio_Config *cfg);
int harkio_Config_getSignalMax(harkio_Config *cfg);

char* harkio_Config_getComment(harkio_Config *cfg);

int harkio_Config_setSynchronousAverage(harkio_Config *cfg, int value);
int harkio_Config_setTSPpath(harkio_Config *cfg, const char *value);
int harkio_Config_setTSPoffset(harkio_Config *cfg, int value);
int harkio_Config_setPeakSearchFrom(harkio_Config *cfg, int value);
int harkio_Config_setPeakSearchTo(harkio_Config *cfg, int value);
int harkio_Config_setNfft(harkio_Config *cfg, int value);
int harkio_Config_setComment(harkio_Config *cfg, const char *value);
int harkio_Config_setSamplingRate(harkio_Config *cfg, int value);
int harkio_Config_setTSPlength(harkio_Config *cfg, int value);
int harkio_Config_setSignalMax(harkio_Config *cfg, int value);

int harkio_Config_isEqual(harkio_Config *a, harkio_Config *b);
void harkio_Config_print(harkio_Config *cfg);
